@@ -3,7 +3,7 @@
  *  BlueZ - Bluetooth protocol stack for Linux
  *
  *  Copyright (C) 2006-2007  Nokia Corporation
- *  Copyright (C) 2004-2008  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2004-2009  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -39,9 +39,8 @@
 #define AVRCP_TARGET_UUID	"0000110C-0000-1000-8000-00805F9B34FB"
 
 /* Move these to respective .h files once they exist */
-#define AUDIO_SOURCE_INTERFACE		"org.bluez.Source"
+#define AUDIO_SOURCE_INTERFACE		"org.bluez.AudioSource"
 #define AUDIO_CONTROL_INTERFACE		"org.bluez.Control"
-#define AUDIO_TARGET_INTERFACE		"org.bluez.Target"
 
 struct source;
 struct control;
@@ -51,6 +50,8 @@ struct headset;
 struct gateway;
 
 struct audio_device {
+	struct btd_device *btd_dev;
+
 	DBusConnection *conn;
 	char *path;
 	bdaddr_t src;
